@@ -1,15 +1,16 @@
 #!/bin/bash
-# List the planets.
+# Listing the planets.
 
 for planet in Mercury Venus Earth Mars Jupiter Saturn Uranus Neptune Pluto
 do
-  echo $planet
+  echo $planet  # Each planet on a separate line.
 done
 
 echo
 
-# Entire 'list' enclosed in quotes creates a single variable.
 for planet in "Mercury Venus Earth Mars Jupiter Saturn Uranus Neptune Pluto"
+# All planets on same line.
+# Entire 'list' enclosed in quotes creates a single variable.
 do
   echo $planet
 done
