@@ -25,7 +25,7 @@ done &lt;data-file
 
 echo "------------------------------------------------"
 
-# Use $IFS (Internal File Separator variable) to split a line of input to
+# Use $IFS (Internal Field Separator variable) to split a line of input to
 # "read", if you do not want the default to be whitespace.
 
 echo "List of all users:"
@@ -37,4 +37,21 @@ done &lt;/etc/passwd   # I/O redirection.
 IFS=$OIFS              # Restore originial $IFS.
 # This code snippet also by Heiner Steven.
 
+
+
+#  Setting the $IFS variable within the loop itself
+#+ eliminates the need for storing the original $IFS
+#+ in a temporary variable.
+#  Thanks, Dim Segebart, for pointing this out.
+echo "------------------------------------------------"
+echo "List of all users:"
+
+while IFS=: read name passwd uid gid fullname ignore
+do
+  echo "$name ($fullname)"
+done &lt;/etc/passwd   # I/O redirection.
+
+echo
+echo "\$IFS still $IFS"
+
 exit 0
